models.CategoryList
models.CategoryList(items=list())Container for meal category data.
Used for endpoints that return meal categories available in TheMealDB.
Attributes
| Name | Description |
|---|---|
| categories | Get all category names from the list. |
models.CategoryList(items=list())Container for meal category data.
Used for endpoints that return meal categories available in TheMealDB.
| Name | Description |
|---|---|
| categories | Get all category names from the list. |