get_meal_by_name

MealDB.get_meal_by_name(name)

Retrieves detailed meal information by searching for a meal name.

Parameters

Name Type Description Default
name str The name of the meal to search for (e.g., ‘Arrabiata’, ‘Potato Salad’). required

Returns

Name Type Description
MealDetails MealDetails object containing detailed meal information.

Raises

Name Type Description
httpx.HTTPError Check httpx’s documentation for all possible exceptions.
httpx.HTTPStatusError If the API returns a non-2xx status code.