list_all_meals

MealDB.list_all_meals(letter)

Retrieves meals starting with a specific letter.

Parameters

Name Type Description Default
letter str The first letter to search for (e.g., ‘a’, ‘b’, ‘c’). required

Returns

Name Type Description
MealDetails MealDetails object containing all meals starting with the specified letter.

Raises

Name Type Description
httpx.HTTPError Check httpx’s documentation for all possible exceptions.
httpx.HTTPStatusError If the API returns a non-2xx status code.