from_response

models.BaseList.from_response(data, key='meals')

Create an instance from an API response dictionary.

Parameters

Name Type Description Default
data dict The API response dictionary. required
key str The key to extract from the response. Defaults to ‘meals’. 'meals'

Returns

Name Type Description
BaseList An instance of the class with items populated from the response.